package com.hw.ems.base.mapper;



import com.hw.ems.base.domain.BaseTypeRelation;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 计量与类型对应关系Mapper接口
 *
 * @author YinQ
 * @date 2023-04-07
 */
@Mapper
public interface BaseTypeRelationMapper
{
    /**
     * 查询计量与类型对应关系
     *
     * @param objid 计量与类型对应关系主键
     * @return 计量与类型对应关系
     */
    public BaseTypeRelation selectBaseTypeRelationByObjid(Long objid);

    /**
     * 查询计量与类型对应关系列表
     *
     * @param baseTypeRelation 计量与类型对应关系
     * @return 计量与类型对应关系集合
     */
    public List<BaseTypeRelation> selectBaseTypeRelationList(BaseTypeRelation baseTypeRelation);

    /**
     * 仅查询查询园区下一级计量与类型对应关系列表
     *
     * @param baseTypeRelation 计量与类型对应关系
     * @return 计量与类型对应关系集合
     */
    public List<BaseTypeRelation> selectFirstOrderTypeRelationList(BaseTypeRelation baseTypeRelation);

    /**
     * 新增计量与类型对应关系
     *
     * @param baseTypeRelation 计量与类型对应关系
     * @return 结果
     */
    public int insertBaseTypeRelation(BaseTypeRelation baseTypeRelation);

    /**
     * 修改计量与类型对应关系
     *
     * @param baseTypeRelation 计量与类型对应关系
     * @return 结果
     */
    public int updateBaseTypeRelation(BaseTypeRelation baseTypeRelation);

    /**
     * 删除计量与类型对应关系
     *
     * @param objid 计量与类型对应关系主键
     * @return 结果
     */
    public int deleteBaseTypeRelationByObjid(Long objid);

    /**
     * 批量删除计量与类型对应关系
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseTypeRelationByObjids(String[] objids);
}
